=============================
pypowervm - Version Reference
=============================
Version 1.0.0.1
---------------
- Minor bug fixes

Version 1.0.0.0
---------------
Initial stable release.  See the README.rst_ for details.

.. _README.rst: README.rst

Version 0.0.2
-------------
- Enhanced metrics gathering.
- Move Python 3 support to version 3.4.

Version 0.0.1
-------------
Note this is not a full release.  It is used for testing and development
purposes.  See the README.rst_ for more versioning information.

- Initial development of project structure.
- Adapter for communicating with the API Server.
- Session management and authentication.
- Wrappers for easy interaction with REST Entries and Elements.  Supports
  CRUD operations.
- Tasks for standard operations against the system.
- Unit tests.
